Struct EnabledCheckData

pub struct EnabledCheckData {
    command_name_cache: Arc<Mutex<Vec<String>>>,
    command_lookup: Arc<Mutex<HashMap<usize, String>>>,
}

Fields

command_name_cache: Arc<Mutex<Vec<String>>>

The set of all commands as strings.

command_lookup: Arc<Mutex<HashMap<usize, String>>>

A way to look up commands by CommandOptions and fn addr.

XXX MASSIVE HACK XXX This uses the addresses of the names field of CommandOptions impls in order to compare commands. This is necessary as this is all serenity gives to Check functions. The only reason this works is because the serenity macro for making commands is used as the only way to make commands, as it recreates each names array for each command uniquely.

Implementations

Source

impl EnabledCheckData

pub fn new() -> Self

Make a new EnabledCheckData.

pub fn add_groups(&self, groups: &[&CommandGroup])

Add a group to have its commands enabled/disabled.

pub fn get_command_name_from_options( &self, options: &CommandOptions, ) -> Option<String>

pub fn get_command_names(&self) -> MutexGuard<'_, RawMutex, Vec<String>>

Returns a mutex guard to the list of command names.